package com.example.mynotepad.Dialogs.FoldersCustomDialog;

import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.graphics.drawable.ColorDrawable;
import android.view.View;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import com.example.mynotepad.MainActivity;
import com.example.mynotepad.MenuFeatures.AllNotes.DataBase.FoldersEntity;
import com.example.mynotepad.MenuFeatures.AllNotes.DataBase.NoteDataBase;
import com.example.mynotepad.R;

import java.util.ArrayList;
import java.util.List;

public class CreateNewFolderDialog {
    private TextView cancel, done;
    private EditText folderName;
    private final OnFolderCreatedListener listener;

    public CreateNewFolderDialog(OnFolderCreatedListener listener) {
        this.listener = listener;
    }

    public void showDialog(Context context) {
        Dialog dialog = new Dialog(context);
        dialog.getWindow().setBackgroundDrawable(new ColorDrawable(android.graphics.Color.TRANSPARENT));
        dialog.setCancelable(true);
        dialog.setContentView(R.layout.dialog_create_new_folder);
        cancel = dialog.findViewById(R.id.cancel);
        done = dialog.findViewById(R.id.done);
        folderName = dialog.findViewById(R.id.folderName);
        addListener(dialog ,context);
        dialog.show();
    }

    private void addListener(final Dialog dialog , final Context context) {
        cancel.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                dialog.dismiss();
            }
        });

        done.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (folderNameIsAcceptable(folderName.getText().toString() , context)) {
                    //save new folder in dataBase
                    FoldersEntity folder = new FoldersEntity(folderName.getText().toString());
                    NoteDataBase.getInstance(context).foldersDAO().insertFolder(folder); // such this method
                    listener.onCreated(folder);

                    dialog.dismiss();
                }
            }
        });
    }

    private boolean folderNameIsAcceptable(String newFolderName , Context context) {
        if (!newFolderName.equals("")) {
            List<FoldersEntity> foldersArray = NoteDataBase.getInstance(context).foldersDAO().getAllFolders();
            if (foldersArray == null)
                return true;//if it is first time we wanna create a folder no need to check being unique
            for (int i = 0; i < foldersArray.size(); i++) {
                System.out.println(foldersArray.get(i).getFolderName());
                if (foldersArray.get(i).getFolderName().equals(newFolderName)) {
                    Toast.makeText(context, "this folder already exists", Toast.LENGTH_SHORT).show();
                    return false;
                }
            }
            return true;
        }
        Toast.makeText(context, "you should enter a name to create new folder", Toast.LENGTH_SHORT).show();
        return false;
    }

    public interface OnFolderCreatedListener {
        void onCreated(FoldersEntity folder);
    }
}
